@@ -39,6 +39,8 @@ LB_EXT_IDS_POOL_PREFIX = 'pool_'
 LB_EXT_IDS_LISTENER_PREFIX = 'listener_'
 LB_EXT_IDS_MEMBER_PREFIX = 'member_'
 LB_EXT_IDS_HM_KEY = 'octavia:healthmonitor'
+LB_EXT_IDS_HM_POOL_KEY = 'octavia:pool_id'
+LB_EXT_IDS_HM_VIP = 'octavia:vip'
 LB_EXT_IDS_HMS_KEY = 'octavia:healthmonitors'
 LB_EXT_IDS_VIP_KEY = 'neutron:vip'
 LB_EXT_IDS_VIP_FIP_KEY = 'neutron:vip_fip'
@@ -112,3 +114,7 @@ HM_EVENT_MEMBER_PORT_OFFLINE = ['offline']
 
 # max timeout for request
 MAX_TIMEOUT_REQUEST = 5
+
+AFFINITY_TIMEOUT = "affinity_timeout"
+# This driver only supports SOURCE_IP sesssion persistency option
+OVN_NATIVE_SESSION_PERSISTENCE = [constants.SESSION_PERSISTENCE_SOURCE_IP]
