@@ -68,6 +68,16 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                 user_fault_string=msg,
                 operator_fault_string=msg)
 
+    def _check_for_supported_session_persistence(self, session):
+        if (session and
+                session.get("type") not in
+                ovn_const.OVN_NATIVE_SESSION_PERSISTENCE):
+            msg = _('OVN provider does not support %s session persistence. '
+                    'Only SOURCE_IP type is supported.') % session.type
+            raise driver_exceptions.UnsupportedOptionError(
+                user_fault_string=msg,
+                operator_fault_string=msg)
+
     def _check_for_allowed_cidrs(self, allowed_cidrs):
         # TODO(haleyb): add support for this
         if isinstance(allowed_cidrs, o_datamodels.UnsetType):
@@ -140,6 +150,11 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                         'admin_state_up': admin_state_up}
         request = {'type': ovn_const.REQ_TYPE_POOL_CREATE,
                    'info': request_info}
+        if not isinstance(
+                pool.session_persistence, o_datamodels.UnsetType):
+            self._check_for_supported_session_persistence(
+                pool.session_persistence)
+            request['info']['session_persistence'] = pool.session_persistence
         self._ovn_helper.add_request(request)
         if pool.healthmonitor is not None and not isinstance(
                 pool.healthmonitor, o_datamodels.UnsetType):
@@ -170,6 +185,12 @@ class OvnProviderDriver(driver_base.ProviderDriver):
 
         if not isinstance(new_pool.admin_state_up, o_datamodels.UnsetType):
             request_info['admin_state_up'] = new_pool.admin_state_up
+        if not isinstance(
+                new_pool.session_persistence, o_datamodels.UnsetType):
+            self._check_for_supported_session_persistence(
+                new_pool.session_persistence)
+            request_info['session_persistence'] = (
+                new_pool.session_persistence)
         request = {'type': ovn_const.REQ_TYPE_POOL_UPDATE,
                    'info': request_info}
         self._ovn_helper.add_request(request)
@@ -329,25 +350,6 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         self._ovn_helper.add_request(request)
 
     def member_update(self, old_member, new_member):
-        # NOTE(froyo): OVN provider allow to create member without param
-        # subnet_id, in that case the driver search it according to the
-        # pool_id, but it is not propagated to Octavia. In this case, if
-        # the member is updated, Octavia send the object without subnet_id.
-        subnet_id = old_member.subnet_id
-        if (isinstance(subnet_id, o_datamodels.UnsetType) or not subnet_id):
-            subnet_id, subnet_cidr = self._ovn_helper._get_subnet_from_pool(
-                old_member.pool_id)
-            if not (subnet_id and
-                    self._ovn_helper._check_ip_in_subnet(new_member.address,
-                                                         subnet_cidr)):
-                msg = _('Subnet is required, or Loadbalancer associated with '
-                        'Pool must have a subnet, for Member update '
-                        'with OVN Provider Driver if it is not the same as '
-                        'LB VIP subnet')
-                raise driver_exceptions.UnsupportedOptionError(
-                    user_fault_string=msg,
-                    operator_fault_string=msg)
-
         # Validate monitoring options if present
         self._check_member_monitor_options(new_member)
         if new_member.address and self._ip_version_differs(new_member):
@@ -356,7 +358,6 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                         'address': old_member.address,
                         'protocol_port': old_member.protocol_port,
                         'pool_id': old_member.pool_id,
-                        'subnet_id': subnet_id,
                         'old_admin_state_up': old_member.admin_state_up}
         if not isinstance(new_member.admin_state_up, o_datamodels.UnsetType):
             request_info['admin_state_up'] = new_member.admin_state_up
@@ -366,7 +367,6 @@ class OvnProviderDriver(driver_base.ProviderDriver):
 
     def member_batch_update(self, pool_id, members):
         request_list = []
-        skipped_members = []
         pool_key, ovn_lb = self._ovn_helper._find_ovn_lb_by_pool_id(pool_id)
         external_ids = copy.deepcopy(ovn_lb.external_ids)
         pool = external_ids[pool_key]
@@ -374,10 +374,16 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         members_to_delete = copy.copy(existing_members)
         pool_subnet_id = None
         for member in members:
-            if (self._check_monitor_options(member) or
-                    member.address and self._ip_version_differs(member)):
-                skipped_members.append(member.member_id)
-                continue
+            # NOTE(froyo): in order to keep sync with Octavia DB, we raise
+            # not supporting exceptions as soon as posible, considering the
+            # full request as not valid
+            if (self._check_monitor_options(member)):
+                msg = 'OVN provider does not support monitor options'
+                raise driver_exceptions.UnsupportedOptionError(
+                    user_fault_string=msg,
+                    operator_fault_string=msg)
+            if (member.address and self._ip_version_differs(member)):
+                raise ovn_exc.IPVersionsMixingNotSupportedError()
             # NOTE(froyo): if subnet_id not provided, lets try to get it
             # from the member pool_id
             subnet_id = member.subnet_id
@@ -425,7 +431,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
 
         for member in members_to_delete:
             member_info = member.split('_')
-            member_ip, member_port, subnet_id = (
+            member_ip, member_port, subnet_id, member_id = (
                 self._ovn_helper._extract_member_info(member)[0])
             request_info = {'id': member_info[1],
                             'address': member_ip,
@@ -437,14 +443,21 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                        'info': request_info}
             request_list.append(request)
 
+            # NOTE(mjozefcz): If LB has FIP on VIP
+            # and member had FIP we can decentralize
+            # the traffic now.
+            request_info = {'id': member_id,
+                            'address': member_ip,
+                            'pool_id': pool_id,
+                            'action': ovn_const.REQ_INFO_MEMBER_DELETED}
+            if len(member_info) == 4:
+                request_info['subnet_id'] = subnet_id
+            request = {'type': ovn_const.REQ_TYPE_HANDLE_MEMBER_DVR,
+                       'info': request_info}
+            request_list.append(request)
+
         for request in request_list:
             self._ovn_helper.add_request(request)
-        if skipped_members:
-            msg = (_('OVN provider does not support monitor options, '
-                     'so following members skipped: %s') % skipped_members)
-            raise driver_exceptions.UnsupportedOptionError(
-                user_fault_string=msg,
-                operator_fault_string=msg)
 
     def create_vip_port(self, lb_id, project_id, vip_dict,
                         additional_vip_dicts=None):
@@ -464,15 +477,18 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         # TODO(gthiemonge): implement additional_vip_dicts
         try:
             port = self._ovn_helper.create_vip_port(
-                project_id, lb_id, vip_dict)['port']
+                project_id, lb_id, vip_dict)
             vip_dict[constants.VIP_PORT_ID] = port['id']
             vip_dict[constants.VIP_ADDRESS] = (
                 port['fixed_ips'][0]['ip_address'])
         except Exception as e:
             kwargs = {}
-            if hasattr(e, 'message'):
-                kwargs = {'user_fault_string': e.message,
-                          'operator_fault_string': e.message}
+            for attr in ('details', 'message'):
+                if hasattr(e, attr):
+                    value = getattr(e, attr)
+                    kwargs = {'user_fault_string': value,
+                              'operator_fault_string': value}
+                    break
             raise driver_exceptions.DriverError(
                 **kwargs)
         return vip_dict, []
